@@ -4,7 +4,7 @@ __author__ = """Lars Claussen"""
 __email__ = "claussen.lars@nelen-schuurmans.nl"
 __version__ = "0.1.1"
 
-from cmd_client.plugins.models import AppRegistry
+from threedi_cmd.plugins.models import AppRegistry
 
 from functools import lru_cache
 
