@@ -1,4 +1,4 @@
-from cmd_client.plugins.models import AppMeta, AppRegistry
+from threedi_cmd.plugins.models import AppMeta, AppRegistry
 from threedi_cmd_statistics.commands.apps import statistics_app, customers_app
 
 statistics_meta = AppMeta(
